@@ -595,55 +595,56 @@ static int check_dir(DOS_FS *fs,DOS_FILE **root,int dots)
 	    }
 	}
 	/* don't check for duplicates of the volume label */
-	skip = !!((*walk)->dir_ent.attr & ATTR_VOLUME);
-	scan = &(*walk)->next;
-	while (*scan && !skip) {
-	    if (!((*scan)->dir_ent.attr & ATTR_VOLUME) &&
-		!strncmp((*walk)->dir_ent.name,(*scan)->dir_ent.name,MSDOS_NAME
-	      )) {
-		printf("%s\n  Duplicate directory entry.\n  First  %s\n",
-		  path_name(*walk),file_stat(*walk));
-		printf("  Second %s\n",file_stat(*scan));
-		if (interactive)
-		    printf("1) Drop first\n2) Drop second\n3) Rename first\n"
-		      "4) Rename second\n5) Auto-rename first\n"
-		      "6) Auto-rename second\n");
-		else printf("  Auto-renaming second.\n");
-		switch (interactive ? get_key("123456","?") : '6') {
-		    case '1':
+	if (!((*walk)->dir_ent.attr & ATTR_VOLUME)) {
+	    scan = &(*walk)->next;
+	    skip = 0;
+	    while (*scan && !skip) {
+		if (!((*scan)->dir_ent.attr & ATTR_VOLUME) &&
+		    !strncmp((*walk)->dir_ent.name,(*scan)->dir_ent.name,MSDOS_NAME)) {
+		    printf("%s\n  Duplicate directory entry.\n  First  %s\n",
+			   path_name(*walk),file_stat(*walk));
+		    printf("  Second %s\n",file_stat(*scan));
+		    if (interactive)
+			printf("1) Drop first\n2) Drop second\n3) Rename first\n"
+			       "4) Rename second\n5) Auto-rename first\n"
+			       "6) Auto-rename second\n");
+		    else printf("  Auto-renaming second.\n");
+		    switch (interactive ? get_key("123456","?") : '6') {
+		      case '1':
 			drop_file(fs,*walk);
 			*walk = (*walk)->next;
 			skip = 1;
 			break;
-		    case '2':
+		      case '2':
 			drop_file(fs,*scan);
 			*scan = (*scan)->next;
 			continue;
-		    case '3':
+		      case '3':
 			rename_file(*walk);
 			printf("  Renamed to %s\n",path_name(*walk));
 			redo = 1;
 			break;
-		    case '4':
+		      case '4':
 			rename_file(*scan);
 			printf("  Renamed to %s\n",path_name(*walk));
 			redo = 1;
 			break;
-		    case '5':
+		      case '5':
 			auto_rename(*walk);
 			printf("  Renamed to %s\n",file_name((*walk)->dir_ent.
 			  name));
 			break;
-		    case '6':
+		      case '6':
 			auto_rename(*scan);
 			printf("  Renamed to %s\n",file_name((*scan)->dir_ent.
 			  name));
 			break;
+		    }
 		}
+		scan = &(*scan)->next;
 	    }
-	    scan = &(*scan)->next;
+	    if (skip) continue;
 	}
-	if (skip) continue;
 	if (!redo) walk = &(*walk)->next;
 	else {
 	    walk = root;
