@@ -95,15 +95,11 @@
 /* Use the _llseek system call directly, because there (once?) was a bug in
  * the glibc implementation of it. */
 #include <linux/unistd.h>
-#ifdef __alpha
+#if defined(__alpha) || defined(__ia64__)
 /* On alpha, the syscall is simply lseek, because it's a 64 bit system. */
 static loff_t llseek( int fd, loff_t offset, int whence )
 {
-    loff_t actual;
-
-    if ((actual = lseek(fd, offset, whence)) != 0)
-	return (loff_t)-1;
-    return actual;
+    return lseek(fd, offset, whence);
 }
 #else
 # ifndef __NR__llseek
@@ -635,6 +631,10 @@ establish_params (int device_num,int size)
 	      param.sect = 18;
 	      param.head = 2;
 	      break;
+	    case 5760:
+	      param.sect = 36;
+	      param.head = 2;
+	      break;
 	    default:
 	      /* fake values */
 	      param.sect = 32;
@@ -1415,7 +1415,7 @@ main (int argc, char **argv)
   printf ("%s " VERSION " (" VERSION_DATE ")\n",
 	   program_name);
 
-  while ((c = getopt (argc, argv, "AcCf:F:Ii:l:m:n:r:s:S:v")) != EOF)
+  while ((c = getopt (argc, argv, "AcCf:F:Ii:l:m:n:r:R:s:S:v")) != EOF)
     /* Scan the command line for options */
     switch (c)
       {
